@@ -15,26 +15,19 @@
 #You should have received a copy of the GNU General Public License
 #along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
-
-"""
-guess which types are the input data. 
-"""
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2013, Nestor Arocha"
 __email__ = "nesaro@gmail.com"
-#FIXME: Use globalconfig memory list
-#TODO: Add Alphabet support
-
 
 import logging
 LOG = logging.getLogger(__name__)
-from pydsl.Memory.Loader import load_checker
 from pydsl.Alphabet.Definition import AlphabetDefinition
 from pydsl.Grammar.Definition import GrammarDefinition
+from pydsl.Check import checker_factory
 
 def extract(grammar, inputdata):
-    """Calls check for every possible slice of text"""
-    checker = load_checker(grammar)
+    """Extract every slice of the input data that belongs to the Grammar Definition"""
+    checker = checker_factory(grammar)
     totallen = len(inputdata)
     if isinstance(grammar, GrammarDefinition):
         try:
