@@ -1,19 +1,19 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-#This file is part of pydsl.
+# This file is part of pydsl.
 #
-#pydsl is free software: you can redistribute it and/or modify
-#it under the terms of the GNU General Public License as published by
-#the Free Software Foundation, either version 3 of the License, or
+# pydsl is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
 #(at your option) any later version.
 #
-#pydsl is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# pydsl is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
 """Production rules"""
 
@@ -26,18 +26,19 @@ __email__ = "nesaro@gmail.com"
 
 
 class Production(object):
+
     def __init__(self, leftside, rightside):
-        #Left side must have at least one non terminal symbol
+        # Left side must have at least one non terminal symbol
         for element in rightside:
             if not isinstance(element, Symbol):
                 raise TypeError
-        self.leftside = leftside
-        self.rightside = rightside
+        self.leftside = tuple(leftside)
+        self.rightside = tuple(rightside)
 
     def __str__(self):
         """Pretty print"""
-        leftstr = " ".join([ x.name for x in self.leftside])
-        rightstr = " ".join([ str(x) for x in self.rightside])
+        leftstr = " ".join([x.name for x in self.leftside])
+        rightstr = " ".join([str(x) for x in self.rightside])
         return leftstr + "::=" + rightstr
 
     def __eq__(self, other):
@@ -62,15 +63,22 @@ class Production(object):
             raise Exception
         return self.leftside[0].name
 
+    def __hash__(self):
+        return hash(self.leftside) & hash(self.rightside)
+
+
+#Only stores a ruleset, and methods to ask properties or validity check
+class BNFGrammar(GrammarDefinition):
 
-class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask properties or validity check 
     def __init__(self, initialsymbol, fulllist, options=None):
+        GrammarDefinition.__init__(self)
         self._initialsymbol = initialsymbol
         for rule in fulllist:
-            if fulllist.count(rule) >1:
+            if fulllist.count(rule) > 1:
                 raise ValueError("Duplicated rule: " + str(rule))
         self.fulllist = fulllist
-        if not options: options = {}
+        if not options:
+            options = {}
         self.options = options
 
     def alphabet(self):
@@ -126,7 +134,7 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
             result.append(EndSymbol())
         for production in self.productions:
             if symbol in production.rightside:
-                nextindex = production.rightside.index(symbol)+1
+                nextindex = production.rightside.index(symbol) + 1
                 while nextindex < len(production.rightside):
                     nextsymbol = production.rightside[nextindex]
                     firstlist = self.first_lookup(nextsymbol)
@@ -142,13 +150,11 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
     @property
     def left_recursive(self):# -> bool:
         """Tests if exists left recursion"""
-        #TODO
         raise NotImplementedError
 
     @property
     def right_recursive(self):# -> bool:
         """Tests if exists right recursion"""
-        #TODO
         raise NotImplementedError
 
     @property
@@ -158,7 +164,7 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
         return UnknownSymbol in self.fulllist
 
     def __eq__(self, other):
-        if not isinstance(other,BNFGrammar):
+        if not isinstance(other, BNFGrammar):
             return False
         if self._initialsymbol != other.initialsymbol:
             return False
@@ -187,13 +193,15 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
 
     def getProductionsBySide(self, symbollist, side = "left"):
         result = []
+        if isinstance(symbollist, Symbol):
+            symbollist = [symbollist]
         for rule in self.productions: #FIXME Is iterating over production only
             if side == "left":
                 part = rule.leftside
             elif side == "right":
                 part = rule.rightside
             else:
-                raise KeyError
+                raise ValueError("Unknown side value %s" % (side,))
             if len(part) != len(symbollist):
                 continue
             for ruleindex in range(len(part)):
@@ -219,4 +227,4 @@ class BNFGrammar(GrammarDefinition): #Only stores a ruleset, and methods to ask
         return self.productions.index(rule)
 
     def __str__(self):
-        return str(list(map(str,self.productions)))
+        return str(list(map(str, self.productions)))
