@@ -1,19 +1,19 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-#This file is part of pydsl.
+# This file is part of pydsl.
 #
-#pydsl is free software: you can redistribute it and/or modify
-#it under the terms of the GNU General Public License as published by
-#the Free Software Foundation, either version 3 of the License, or
+# pydsl is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
 #(at your option) any later version.
 #
-#pydsl is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# pydsl is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2013, Nestor Arocha"
@@ -21,6 +21,7 @@ __email__ = "nesaro@gmail.com"
 
 
 class GrammarDefinition(object):
+
     def __init__(self):
         pass
 
@@ -31,7 +32,7 @@ class GrammarDefinition(object):
     @property
     def first(self):# -> set:
         """List of possible first elements"""
-        return [x for x in self.alphabet().grammar_list]
+        return [x for x in self.alphabet().to_list]
 
     @property
     def minsize(self):# -> int:
@@ -71,10 +72,17 @@ class RegularExpressionDefinition(GrammarDefinition):
         import re
         self.regexp = re.compile(regexp, flags)
 
+    def __hash__(self):
+        return hash(self.regexpstr)
+
     def __eq__(self, other):
         if not isinstance(other, RegularExpressionDefinition):
             return False
         return self.regexpstr == other.regexpstr and self.flags == other.flags
+
+    def __str__(self):
+        return self.regexpstr
+
     @property
     def first(self):# -> set:
         i = 0
