@@ -1,21 +1,22 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-#This file is part of pydsl.
+# This file is part of pydsl.
 #
-#pydsl is free software: you can redistribute it and/or modify
-#it under the terms of the GNU General Public License as published by
-#the Free Software Foundation, either version 3 of the License, or
+# pydsl is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
 #(at your option) any later version.
 #
-#pydsl is distributed in the hope that it will be useful,
-#but WITHOUT ANY WARRANTY; without even the implied warranty of
-#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#GNU General Public License for more details.
+# pydsl is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 #
-#You should have received a copy of the GNU General Public License
-#along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License
+# along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
 """Symbols"""
+from pydsl.Check import check
 
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2013, Nestor Arocha"
@@ -49,16 +50,18 @@ class NonTerminalSymbol(Symbol):
             return False
         return self.name == other.name and self.weight == other.weight
 
-class TerminalSymbol(Symbol): 
-    def __init__(self, gd, weight = None, boundariesrules = None):
+
+class TerminalSymbol(Symbol):
+
+    def __init__(self, gd, weight=None, boundariesrules=None):
         if isinstance(gd, StringGrammarDefinition):
             weight = weight or 99
             boundariesrules = len(gd.string)
         else:
             weight = weight or 49
         Symbol.__init__(self, weight)
-        if boundariesrules not in ("min","max","any") and not isinstance(boundariesrules, int):
-            raise TypeError
+        if boundariesrules not in ("min", "max", "any") and not isinstance(boundariesrules, int):
+            raise TypeError("Unknown boundaries rules %s" % boundariesrules)
         if not gd:
             raise Exception
         self.gd = gd
@@ -69,15 +72,12 @@ class TerminalSymbol(Symbol):
 
     def check(self, data):# ->bool:
         """Checks if input is recognized as this symbol"""
-        from pydsl.Memory.Loader import load_checker
-        checker = load_checker(self.gd)
-        return checker.check(data)
+        return check(self.gd, data)
 
     @property
     def first(self):
         return self.gd.first
 
-
     def __eq__(self, other):
         """StringTerminalSymbol are equals if definition and names are equal"""
         try:
