@@ -46,7 +46,7 @@ def __generateWordSymbol(rightside):
         raise TypeError
     br = args[2] #Boundary rule policy
 
-    from pydsl.Memory.Loader import load
+    from pydsl.Config import load
     return TerminalSymbol(load(args[1]), None, br)
 
 
@@ -151,9 +151,8 @@ def load_bnf_file(filepath):
 
 
 def summary_bnf_file(filepath):
-    from pydsl.Memory.File.Python import getFileTuple
+    from pypository.utils import ImmutableDict, getFileTuple
     (_, _, fileBaseName, _) = getFileTuple(filepath)
-    from pydsl.Abstract import ImmutableDict
     return ImmutableDict({"iclass":"BNFGrammar","identifier":fileBaseName, "filepath":filepath})
 
 def str_to_productionset(string):
