@@ -20,14 +20,9 @@
 
 import logging
 LOG = logging.getLogger(__name__)
-from pydsl.Abstract import ImmutableDict
+from pypository.utils import ImmutableDict, getFileTuple, load_module
 import imp
 
-def load_module(filepath, identifier = None):
-    if identifier is None:
-        (_, _, identifier, _) = getFileTuple(filepath)
-    return imp.load_source(identifier, filepath)
-
 def load_python_file(moduleobject):
     """ Try to create an indexable instance from a module"""
     if isinstance(moduleobject, str):
@@ -53,16 +48,15 @@ def load_python_file(moduleobject):
         return PythonGrammar(resultdic)
     elif iclass == "PythonTransformer":
         return resultdic
+    elif iclass == "AlphabetList":
+        from pydsl.Alphabet.Definition import AlphabetListDefinition
+        return AlphabetListDefinition(**resultdic)
+    elif iclass == "pyparsing":
+        return resultdic['root_symbol']
     else:
         raise ValueError(str(moduleobject))
 
 
-def getFileTuple(fullname):
-    import os.path
-    (dirName, fileName) = os.path.split(fullname)
-    (fileBaseName, fileExtension) = os.path.splitext(fileName)
-    return dirName, fileName, fileBaseName, fileExtension
-
 def summary_python_file(modulepath):
     (_, _, fileBaseName, ext) = getFileTuple(modulepath)
     moduleobject = imp.load_source(fileBaseName, modulepath)
