@@ -22,9 +22,14 @@ __email__ = "nesaro@gmail.com"
 
 import logging
 LOG = logging.getLogger(__name__)
+from pydsl.Config import load
+from pydsl.Parser.Parser import parser_factory
 
 
 class Validator(object):
+    """Receives a grammar and an input that doesn't belong to the grammar, 
+    expands the grammar by parsing it, returns a list of what's needed 
+    to become grammar compatible"""
     def __init__(self, grammar):
         self.gd = grammar
 
@@ -34,7 +39,20 @@ class Validator(object):
 
 class BNFValidator(Validator):
     def __call__(self, inputstring):
-        from pydsl.Memory.Loader import load_parser
-        parser = load_parser(self.gd, "descent")
+        parser = parser_factory(self.gd, "descent")
         resulttrees = parser.get_trees(inputstring, True)
-        return resulttrees
+        return [x for x in resulttrees if not x.valid]
+
+
+def validator_factory(grammar):
+    if isinstance(grammar, str):
+        grammar = load(grammar)
+    from pydsl.Grammar.BNF import BNFGrammar
+    if isinstance(grammar, BNFGrammar):
+        return BNFValidator(grammar)
+    else:
+        raise ValueError(grammar)
+
+
+def validate(definition, data):
+    return validator_factory(definition)(data)
\ No newline at end of file
